"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.S3Mock = void 0;
const typescript_helper_functions_1 = require("typescript-helper-functions");
// tslint:disable-next-line: no-var-requires
const AWS = require('aws-sdk');
/**
 * S3 Mock class
 */
class S3Mock extends typescript_helper_functions_1.BaseMock {
    constructor() {
        super(...arguments);
        /**
         * Mock an AWS.S3.CopyObjectOutput response
         */
        this.CopyObjectOutput = {};
        /**
         * Mock an AWS.S3.CreateBucketOutput response
         */
        this.CreateBucketOutput = {};
        /**
         * Mock an AWS.S3.DeleteBucketOutput response
         * Technically does not exist
         */
        this.DeleteBucketOutput = {};
        /**
         * Mock an AWS.S3.DeleteObjectOutput response
         */
        this.DeleteObjectOutput = {};
        /**
         * Mock an AWS.S3.DeleteObjectsOutput response
         */
        this.DeleteObjectsOutput = {};
        /**
         * Mock an AWS.S3.DeleteObjectTaggingOutput response
         */
        this.DeleteObjectTaggingOutput = {};
        /**
         * Mock an AWS.S3.GetObjectOutput response
         * Technically does not exist
         */
        this.GetBucketOutput = {};
        /**
         * Mock an AWS.S3.GetObjectOutput response
         */
        this.GetObjectOutput = { Body: 'mock-body' };
        /**
         * Mock an AWS.S3.GetObjectTaggingOutput response
         */
        this.GetObjectTaggingOutput = {
            TagSet: [{
                    Key: 'Tag1',
                    Value: 'Tag1Value',
                }]
        };
        /**
         * Mock an AWS.S3.HeadBucketOutput response
         * Technically does not exist
         */
        this.HeadBucketOutput = {};
        /**
         * Mock an AWS.S3.Metadata response
         */
        this.HeadObjectOutput = { Metadata: { key1: 'value1' } };
        /**
         * Mocks an AWS.S3.PutObjectOutput response
         */
        this.PutObjectOutput = {};
        /**
         * Mocks an AWS.S3.PutObjectTaggingOutput response
         */
        this.PutObjectTaggingOutput = {};
    }
    /**
     * Create the S3 mock
     */
    CreateMock(returnError) {
        const rejectResponse = new Error(`AWS Error`);
        // implement the AWS responses
        const awsResponses = {
            // copy object response
            copyObject: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.CopyObjectOutput);
                }),
            },
            // create bucket response
            createBucket: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.CreateBucketOutput);
                }),
            },
            // delete bucket response
            deleteBucket: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.DeleteBucketOutput);
                }),
            },
            // delete object response
            deleteObject: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.DeleteObjectOutput);
                }),
            },
            // delete objects response
            deleteObjects: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.DeleteObjectsOutput);
                }),
            },
            // delete object tagging response
            deleteObjectTagging: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.DeleteObjectTaggingOutput);
                }),
            },
            // get object response
            getObject: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.GetObjectOutput);
                }),
            },
            // get object tagging response
            getObjectTagging: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.GetObjectTaggingOutput);
                }),
            },
            // head bucket response
            headBucket: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.HeadBucketOutput);
                }),
            },
            // head object response
            headObject: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.HeadObjectOutput);
                }),
            },
            // put object response
            putObject: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.PutObjectOutput);
                }),
            },
            // put object tagging response
            putObjectTagging: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.PutObjectTaggingOutput);
                }),
            },
        };
        // create the functions
        let functions = new AWS.S3();
        functions = {
            copyObject: () => awsResponses.copyObject,
            createBucket: () => awsResponses.createBucket,
            deleteBucket: () => awsResponses.deleteBucket,
            deleteObject: () => awsResponses.deleteObject,
            deleteObjects: () => awsResponses.deleteObjects,
            deleteObjectTagging: () => awsResponses.deleteObjectTagging,
            getObject: () => awsResponses.getObject,
            getObjectTagging: () => awsResponses.getObjectTagging,
            getSignedUrl: () => (SignedUrl),
            headBucket: () => awsResponses.headBucket,
            headObject: () => awsResponses.headObject,
            putObject: () => awsResponses.putObject,
            putObjectTagging: () => awsResponses.putObjectTagging,
        };
        return functions;
    }
}
exports.S3Mock = S3Mock;
const SignedUrl = 'https://bucket.s3.amazonaws.com/file.ext?AWSAccessKeyId=AccessKeyId&Content-Type=ContentType&Expires=123456789&Signature=Signature';
//# sourceMappingURL=mock.js.map